@@ -1356,6 +1356,9 @@ class GitLabracadabraProject(
                 "items": {
                     "type": "object",
                     "properties": {
+                        "enabled": {
+                            "type": "boolean",
+                        },
                         "url": {
                             "type": "string",
                             "description": "Repository URL",
@@ -1468,53 +1471,6 @@ class GitLabracadabraProject(
                 "description": "Package image mirrors",
                 "items": {
                     "oneOf": [
-                        {
-                            "type": "object",
-                            "description": "Raw source",
-                            "properties": {
-                                "enabled": {
-                                    "type": "boolean",
-                                },
-                                "raw": {
-                                    "type": "object",
-                                    "properties": {
-                                        "default_url": {
-                                            "type": "string",
-                                        },
-                                        "default_package_name": {
-                                            "type": "string",
-                                        },
-                                        "default_package_version": {
-                                            "type": "string",
-                                        },
-                                        "package_files": {
-                                            "type": "array",
-                                            "items": {
-                                                "type": "object",
-                                                "properties": {
-                                                    "url": {
-                                                        "type": "string",
-                                                    },
-                                                    "package_name": {
-                                                        "type": "string",
-                                                    },
-                                                    "package_version": {
-                                                        "type": "string",
-                                                    },
-                                                    "file_name": {
-                                                        "type": "string",
-                                                    },
-                                                },
-                                                "additionalProperties": False,
-                                            },
-                                        },
-                                    },
-                                    "required": ["default_url"],
-                                    "additionalProperties": False,
-                                },
-                            },
-                            "additionalProperties": False,
-                        },
                         {
                             "type": "object",
                             "description": "Github source",
@@ -1600,6 +1556,32 @@ class GitLabracadabraProject(
                             },
                             "additionalProperties": False,
                         },
+                        {
+                            "type": "object",
+                            "description": "PULP_MANIFEST repository",
+                            "properties": {
+                                "enabled": {
+                                    "type": "boolean",
+                                },
+                                "pulp_manifest": {
+                                    "type": "object",
+                                    "properties": {
+                                        "url": {
+                                            "type": "string",
+                                        },
+                                        "package_name": {
+                                            "type": "string",
+                                        },
+                                        "package_version": {
+                                            "type": "string",
+                                        },
+                                    },
+                                    "required": ["url", "package_name"],
+                                    "additionalProperties": False,
+                                },
+                            },
+                            "additionalProperties": False,
+                        },
                         {
                             "type": "object",
                             "description": "PyPI source",
@@ -1633,6 +1615,53 @@ class GitLabracadabraProject(
                             },
                             "additionalProperties": False,
                         },
+                        {
+                            "type": "object",
+                            "description": "Raw source",
+                            "properties": {
+                                "enabled": {
+                                    "type": "boolean",
+                                },
+                                "raw": {
+                                    "type": "object",
+                                    "properties": {
+                                        "default_url": {
+                                            "type": "string",
+                                        },
+                                        "default_package_name": {
+                                            "type": "string",
+                                        },
+                                        "default_package_version": {
+                                            "type": "string",
+                                        },
+                                        "package_files": {
+                                            "type": "array",
+                                            "items": {
+                                                "type": "object",
+                                                "properties": {
+                                                    "url": {
+                                                        "type": "string",
+                                                    },
+                                                    "package_name": {
+                                                        "type": "string",
+                                                    },
+                                                    "package_version": {
+                                                        "type": "string",
+                                                    },
+                                                    "file_name": {
+                                                        "type": "string",
+                                                    },
+                                                },
+                                                "additionalProperties": False,
+                                            },
+                                        },
+                                    },
+                                    "required": ["default_url"],
+                                    "additionalProperties": False,
+                                },
+                            },
+                            "additionalProperties": False,
+                        },
                     ],
                 },
                 "_example": (
@@ -1718,9 +1747,9 @@ class GitLabracadabraProject(
                 },
                 "_example": (
                     "\n"
-                    "    # Mirror debian:bookworm\n"
-                    "    # ... to registry.example.org/mygroup/myproject/library/debian:bookworm:\n"
-                    "    - from: 'debian:bookworm'\n"
+                    "    # Mirror debian:trixie\n"
+                    "    # ... to registry.example.org/mygroup/myproject/library/debian:trixie:\n"
+                    "    - from: 'debian:trixie'\n"
                     "    # Overriding destination:\n"
                     "    - from: 'quay.org/coreos/etcd:v3.4.1'\n"
                     "      to: 'etcd:v3.4.1' # Default would be coreos/etcd:v3.4.1\n"
