@@ -17,17 +17,23 @@
 from __future__ import annotations
 
 from dataclasses import KW_ONLY, dataclass, field
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from typing import Literal
 
 
 @dataclass
 class PackageFile:
     url: str
-    package_type: str
+    package_type: Literal["generic", "helm", "pypi"]
     package_name: str
     package_version: str = "0"
     file_name: str = ""
     _: KW_ONLY
     metadata: dict[str, str] = field(default_factory=dict)
+    force: bool = False
+    delete: bool = False
 
     def __post_init__(self) -> None:
         if not self.file_name:
