@@ -23,6 +23,7 @@ from requests import Session
 from gitlabracadabra import __version__ as gitlabracadabra_version
 
 if TYPE_CHECKING:
+    from gitlabracadabra.packages.destination import Destination
     from gitlabracadabra.packages.package_file import PackageFile
 
 
@@ -34,8 +35,7 @@ class Source:
         self.session = Session()
         self.session.headers["User-Agent"] = f"gitlabracadabra/{gitlabracadabra_version}"
 
-    @property
-    def package_files(self) -> list[PackageFile]:
+    def package_files(self, destination: Destination) -> list[PackageFile]:
         """Return list of package files.
 
         Raises:
