@@ -27,4 +27,4 @@ class TestSource(TestCase):
         """Test package_files method."""
         source = Source()
         with pytest.raises(NotImplementedError):
-            source.package_files  # noqa: B018
+            source.package_files(None)
