@@ -370,7 +370,5 @@ class TestApplicationSettings(TestCaseWithManager):
             },
         )
         assert obj.errors() == []
-        if self.gitlab_version(lt="3"):
-            return
         obj.process()
         assert cass.all_played
