@@ -15,9 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from pathlib import Path
-from unittest import skipIf
 
-from gitlab import __version__ as gitlab_version
 from yaml import safe_load as yaml_safe_load
 
 from gitlabracadabra.objects.project import GitLabracadabraProject
@@ -249,7 +247,6 @@ class TestProject(TestCaseWithManager):
         obj.process()
         assert cass.all_played
 
-    @skipIf(gitlab_version in ["1.6.0"], "python-gitlab without protected tags support")
     @my_vcr.use_cassette
     def test_protected_tags_wildcard(self, cass):
         obj = GitLabracadabraProject(
@@ -271,11 +268,8 @@ class TestProject(TestCaseWithManager):
                 {"name": "v*", "create_access_level": 40},
             )
 
-    @skipIf(gitlab_version in ["1.6.0"], "python-gitlab without protected tags support")
     @my_vcr.use_cassette
     def test_protected_tags_change(self, cass):
-        if self.gitlab_version(lt="3.0"):
-            cass.requests[2].uri = "http://localhost/api/v4/projects/19/protected_tags/v1%2E0"
         obj = GitLabracadabraProject(
             "memory",
             "test/protected_tags",
@@ -295,7 +289,6 @@ class TestProject(TestCaseWithManager):
                 {"name": "v1.0", "create_access_level": 40},
             )
 
-    @skipIf(gitlab_version in ["1.6.0"], "python-gitlab without protected tags support")
     @my_vcr.use_cassette
     def test_protected_tags_delete(self, cass):
         obj = GitLabracadabraProject(
@@ -379,11 +372,8 @@ class TestProject(TestCaseWithManager):
         obj.process()
         assert cass.all_played
 
-    @skipIf(gitlab_version in ["1.11.0", "1.13.0"], "python-gitlab without proper project labels support")
     @my_vcr.use_cassette
     def test_labels(self, cass):
-        if self.gitlab_version(lt="3.2"):
-            cass.requests[4].uri = "http://localhost/api/v4/projects/33/labels?name=delete_me"
         obj = GitLabracadabraProject(
             "memory",
             "test/project_labels",
