@@ -143,7 +143,7 @@ class TestProjectPackageMirrors(TestCaseWithManager):
                 call.info(
                     '%sUploading %s package file "%s" from "%s" version %s (%s)',
                     "[test/test_from_raw] ",
-                    "raw",
+                    "generic",
                     "gpg",
                     "unknown",
                     "0",
@@ -185,7 +185,7 @@ class TestProjectPackageMirrors(TestCaseWithManager):
                 call.info(
                     '%sUploading %s package file "%s" from "%s" version %s (%s)',
                     "[test/test_from_github] ",
-                    "raw",
+                    "generic",
                     "install.sh",
                     "olm",
                     "v0.18.1",
@@ -238,7 +238,7 @@ class TestProjectPackageMirrors(TestCaseWithManager):
                 call.info(
                     '%sUploading %s package file "%s" from "%s" version %s (%s)',
                     "[test/test_from_github] ",
-                    "raw",
+                    "generic",
                     "calicoctl-v3.18.3.tar.gz",
                     "calicoctl",
                     "v3.18.3",
@@ -424,3 +424,74 @@ class TestProjectPackageMirrors(TestCaseWithManager):
             assert destination_logger.mock_calls == []
             assert pypi_logger.mock_calls == []
         assert cass.all_played
+
+    @my_vcr.use_cassette
+    def test_package_mirrors_pulp_manifest(self, cass):
+        """Test package_mirrors, from PULP_MANIFEST.
+
+        Args:
+            cass: VCR cassette.
+        """
+        project = GitLabracadabraProject(
+            "memory",
+            "gitlabracadabra/test-pulp-manifest",
+            {
+                "package_mirrors": [
+                    {
+                        "pulp_manifest": {
+                            "url": "https://fwupd.org/downloads/PULP_MANIFEST",
+                            "package_name": "fwupd",
+                        },
+                    }
+                ],
+            },
+        )
+        assert project.errors() == []
+        with patch("gitlabracadabra.packages.destination.logger", autospec=True) as logger:
+            project.process()
+        assert logger.mock_calls == [
+            call.info(
+                '%sUploading %s package file "%s" from "%s" version %s (%s)',
+                "[gitlabracadabra/test-pulp-manifest] ",
+                "generic",
+                "firmware-07912-stable.xml.gz",
+                "fwupd",
+                "0",
+                "https://fwupd.org/downloads/firmware-07912-stable.xml.gz",
+            ),
+            call.info(
+                '%sUploading %s package file "%s" from "%s" version %s (%s)',
+                "[gitlabracadabra/test-pulp-manifest] ",
+                "generic",
+                "firmware.xml.gz.jcat",
+                "fwupd",
+                "0",
+                "https://fwupd.org/downloads/firmware.xml.gz.jcat",
+            ),
+            call.info(
+                '%sUploading %s package file "%s" from "%s" version %s (%s)',
+                "[gitlabracadabra/test-pulp-manifest] ",
+                "generic",
+                "PULP_MANIFEST",
+                "fwupd",
+                "0",
+                "https://fwupd.org/downloads/PULP_MANIFEST",
+            ),
+            call.info(
+                '%Deleting %s package file "%s" from "%s" version %s',
+                "[gitlabracadabra/test-pulp-manifest] ",
+                "generic",
+                "firmware-07912-stable.xml.gz",
+                "fwupd",
+                "0",
+            ),
+            call.info(
+                '%Deleting %s package file "%s" from "%s" version %s',
+                "[gitlabracadabra/test-pulp-manifest] ",
+                "generic",
+                "PULP_MANIFEST",
+                "fwupd",
+                "0",
+            ),
+        ]
+        assert cass.all_played
